SystemOrganization addCategory: #'BP2010H1-CI-Srv'!

!S2JAbstractTest methodsFor: '*BP2010H1-CI-Srv' stamp: 'srv 1/26/2011 16:23'!
setUp

	self class isOnCIServer ifTrue: [
		S2JCodeFactory clearCache.
		S2JPrettyCodeFactory clearCache.
		]! !

!AioEventHandler class methodsFor: '*BP2010H1-CI-Srv' stamp: 'srv 1/27/2011 17:52'!
aioPluginPresent
	"Answer true if an AIO plugin is available. The value of AioPluginPresent
	is cleared at startup time, and is reestablished once for each Squeak session."

	"AioEventHandler aioPluginPresent"

	^ AioPluginPresent
		ifNil: [AioPluginPresent := self basicNew primAioModuleVersionString notNil.
			"AioPluginPresent ifFalse:
				[self inform: 'AioPlugin not present, AioEventHandler will use polling input']."
			^ AioPluginPresent]! !

Object subclass: #ServerScripts
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'BP2010H1-CI-Srv'!

ServerScripts class
	instanceVariableNames: 'lastVersion lastGitVersion'!

ServerScripts class
	instanceVariableNames: 'lastVersion lastGitVersion'!

!ServerScripts class methodsFor: 'scripts' stamp: 'srv 2/21/2011 18:20'!
gitUpdated
	| version |
	version := (CommandShell pipeline: '/home/tom/gitVersion.sh') output.
	lastGitVersion ~= version ifTrue: [ lastGitVersion := version. ^true].
	^false.! !

!ServerScripts class methodsFor: 'scripts' stamp: 'srv 1/5/2011 09:25'!
loadNewestMonticelloPackage
	| repoInspector index versionList |
	repoInspector := MCFileRepositoryInspector repository: self repository workingCopy: nil.
	repoInspector packageSelection: 0. "In order to get a list of _all_ version, no package should be preselected."
	versionList := repoInspector versionList.
	index := 1.
	[ (self packages anySatisfy: [ :each | (versionList at: index) asString beginsWith: each asString ])
		or: [ index >= repoInspector versionList size ] ] whileFalse: [ index := index + 1 ].
	repoInspector versionSelection: index.
	lastVersion == repoInspector version
		ifFalse: [ 
			lastVersion := repoInspector version.
			repoInspector load.
			Transcript
				cr;
				show: 'Neue Version geladen: ' , repoInspector version name.
			 ^ true ]
		ifTrue: [ 
			Transcript
				cr;
				show: 'Keine neue Version geladen'.
			^ false ]! !

!ServerScripts class methodsFor: 'scripts' stamp: 'srv 2/21/2011 18:18'!
loadNewestVersion
	^ self loadNewestMonticelloPackage or: [ self gitUpdated ].! !

!ServerScripts class methodsFor: 'configuration' stamp: 'srv 12/16/2010 18:52'!
packages

	 ^ #( Squeak2JS BP2010H1-CI-Srv ).! !

!ServerScripts class methodsFor: 'configuration' stamp: 'srv 12/15/2010 14:15'!
repository
	^ MCHttpRepository allInstances at: 27	"hirschfeld squeaksource"! !

!ServerScripts class methodsFor: 'scripts' stamp: 'srv 12/15/2010 15:17'!
runTests
	| suite |
	suite := TestSuite new.
	self testCases
		do: [:each | each isAbstract
				ifFalse: [each addToSuiteFromSelectors: suite]].
	suite name: 'S2J Test'.
	^ TestRunner new runSuite: suite; result! !

!ServerScripts class methodsFor: 'configuration' stamp: 'srv 1/26/2011 16:28'!
testCases
^ { S2JTestCase.
		S2JAbstractTest. 
			S2JPrinterTest.
			S2JPrettyPrinterTest.
		S2JParserTest.
		S2JSqueakAstToJsAstTest.
	S2JCodeFactoryTest.
	S2JJavascriptTest.
	S2JSwazooTests.
		S2JCometHandlerTests.
		S2JDispatcherTests.
		S2JWebSocketHandlerTests }! !

Morph subclass: #TrafficLight
	instanceVariableNames: 'yellow green red'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'BP2010H1-CI-Srv'!

!TrafficLight commentStamp: 'srv 12/15/2010 16:15' prior: 0!
"| tf |
tf := TrafficLight new.
10 timesRepeat: [
	tf switch.
	tf toggleAll.
	(Delay forSeconds: 1) wait
	]."!

!TrafficLight class methodsFor: 'configuration' stamp: 'srv 12/16/2010 18:05'!
colors

	 ^ #(red green yellow)! !

!TrafficLight class methodsFor: 'plugs' stamp: 'srv 12/15/2010 15:49'!
green

	 ^1! !

!TrafficLight class methodsFor: 'plugs' stamp: 'srv 12/15/2010 15:49'!
red

	 ^3! !

!TrafficLight class methodsFor: 'plugs' stamp: 'srv 12/15/2010 15:49'!
yellow

	 ^2! !

!TrafficLight methodsFor: 'running tests' stamp: 'srv 2/22/2011 17:23'!
computeColor: aTestRunnerResult
	
	self red: aTestRunnerResult unexpectedErrorCount + aTestRunnerResult unexpectedFailureCount > 0.
	self yellow: aTestRunnerResult expectedDefectCount + aTestRunnerResult unexpectedPassCount > 0.
	self green: (self red | self yellow) not.! !

!TrafficLight methodsFor: 'accessing' stamp: 'srv 12/15/2010 15:58'!
green
	^ green! !

!TrafficLight methodsFor: 'accessing' stamp: 'srv 12/15/2010 15:58'!
green: anObject
	^ green := anObject! !

!TrafficLight methodsFor: 'initialization' stamp: 'srv 12/16/2010 18:48'!
initialize

	super initialize.
	yellow := red := green := false.
	self openInWorld.
	self runTests.
	self startStepping.
	"self buildMorphs."! !

!TrafficLight methodsFor: 'traffic light' stamp: 'srv 2/15/2011 12:09'!
onlyGreen

	red := yellow := false.
	green := true.! !

!TrafficLight methodsFor: 'traffic light' stamp: 'srv 2/15/2011 12:09'!
onlyRed

	yellow := green := false.
	red := true.! !

!TrafficLight methodsFor: 'traffic light' stamp: 'srv 2/15/2011 12:08'!
onlyYellow

	red := green := false.
	yellow := true.! !

!TrafficLight methodsFor: 'accessing' stamp: 'srv 12/15/2010 15:58'!
red
	^ red! !

!TrafficLight methodsFor: 'accessing' stamp: 'srv 12/15/2010 15:58'!
red: anObject
	^ red := anObject! !

!TrafficLight methodsFor: 'running tests' stamp: 'srv 2/15/2011 11:55'!
runTests
	| result |
	self switchOn.
	result := ServerScripts runTests.
	self computeColor: result.
	self switch! !

!TrafficLight methodsFor: 'stepping and presenter' stamp: 'srv 2/21/2011 18:20'!
step
	ServerScripts loadNewestVersion
		ifTrue: [ self runTests ]! !

!TrafficLight methodsFor: 'testing' stamp: 'srv 1/5/2011 09:27'!
stepTime

	 ^ 100000! !

!TrafficLight methodsFor: 'traffic light' stamp: 'srv 2/15/2011 12:45'!
switch
	| colors |
	colors := OrderedCollection new.
	CommandShell command: 
		(#(#red #green #yellow)
			inject: 'sispmctl ' into: [ :command :color | 
				(self perform: color)
					ifTrue: [ command := command , '-o '. colors add: (Color perform: color) ]
					ifFalse: [ command := command , '-f ' ].
				command, (self class perform: color), ' ']),
			';exit'.
	"Sometimes, the commandShell communication is deferred by test-execution"
	(Delay forSeconds: 0.3) wait.
	
	self color: 
		(colors size caseOf: {
			[0] -> [ Color black ].
			[1] -> [ colors first ].
			[2] -> [ colors first mixed: 0.5 with: colors second ].
			[3] -> [ Color white ]
		}).! !

!TrafficLight methodsFor: 'traffic light' stamp: 'srv 2/15/2011 11:58'!
switchAll: aBoolean

	red := yellow := green := aBoolean.
	self switch.! !

!TrafficLight methodsFor: 'traffic light' stamp: 'srv 2/15/2011 12:03'!
switchOn
	self switchAll: true.! !

!TrafficLight methodsFor: 'traffic light' stamp: 'srv 2/15/2011 11:59'!
toggleAll

	"Only one switch"
	yellow := yellow not.
	green := green not.
	self toggleRed.! !

!TrafficLight methodsFor: 'traffic light' stamp: 'srv 12/16/2010 17:57'!
toggleGreen
	
	self green: self green not.
	self switch.
	^ self green! !

!TrafficLight methodsFor: 'traffic light' stamp: 'srv 12/16/2010 17:57'!
toggleRed
	
	self red: self red not.
	self switch.
	^ self red! !

!TrafficLight methodsFor: 'traffic light' stamp: 'srv 12/16/2010 17:57'!
toggleYellow
	
	self yellow: self yellow not.
	self switch.
	^ self yellow! !

!TrafficLight methodsFor: 'accessing' stamp: 'srv 12/15/2010 15:58'!
yellow
	^ yellow! !

!TrafficLight methodsFor: 'accessing' stamp: 'srv 12/15/2010 15:58'!
yellow: anObject
	yellow := anObject! !
